@@ -479,13 +479,13 @@ class SSLIOHandler(IOHandler):
         if self._ssl_accepting:
             self._do_ssl_handshake()
             return
-        super(SSLIOHandler, self)._handle_read()
+        super(SSLIOHandler, self)._handle_recv()
 
     def _handle_send(self):
         if self._ssl_accepting:
             self._do_ssl_handshake()
             return
-        super(SSLIOHandler, self)._handle_write()
+        super(SSLIOHandler, self)._handle_send()
 
     def connect(self, address, callback=None, server_hostname=None):
         # Save the user's callback and run it after the ssl handshake
@@ -514,7 +514,11 @@ class SSLIOHandler(IOHandler):
             return -1
 
         try:
-            return self._socket.recv_into(recv_buffer, self._recv_chunk_size)
+            bytes = self._socket.read(self._recv_chunk_size)
+            read = len(bytes)
+            recv_buffer[:read] = bytes
+
+            return read
         except ssl.SSLError as e:
             # SSLError is a subclass of socket.error, so this except
             # block must come first.
